==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/Modules/streams/ReadableStreamToSharedBufferSink.h <==
/*
 * Copyright (C) 2017-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */


#pragma once

#include "Exception.h"
#include <JavaScriptCore/Forward.h>
#include <JavaScriptCore/JSCJSValue.h>
#include <span>
#include <wtf/Function.h>
#include <wtf/Ref.h>
#include <wtf/RefCountedAndCanMakeWeakPtr.h>

namespace WebCore {

class ReadableStream;
class ReadableStreamDefaultReader;
class SinkReadRequest;
template<typename> class ExceptionOr;

class ReadableStreamToSharedBufferSink final : public RefCountedAndCanMakeWeakPtr<ReadableStreamToSharedBufferSink> {
public:
    using Result = Variant<std::nullptr_t, std::span<const uint8_t>, JSC::JSValue, Exception>;
    using Callback = Function<void(Result&&)>;
    static Ref<ReadableStreamToSharedBufferSink> create(Callback&& callback) { return adoptRef(*new ReadableStreamToSharedBufferSink(WTFMove(callback))); }
    ~ReadableStreamToSharedBufferSink();

    void pipeFrom(ReadableStream&);
    void clearCallback();
    bool hasCallback() const { return !!m_callback; }

private:
    explicit ReadableStreamToSharedBufferSink(Callback&&);

    friend class SinkReadRequest;
    void enqueue(const Ref<JSC::Uint8Array>&);
    void close();
    void error(Exception&&);
    void error(JSC::JSValue);

    Callback m_callback;
    RefPtr<ReadableStreamDefaultReader> m_reader;
    RefPtr<SinkReadRequest> m_readRequest;
};

} // namespace WebCore

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/Modules/streams/ReadableStreamToSharedBufferSink.h <==
/*
 * Copyright (C) 2017-2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */


#pragma once

#include "Exception.h"
#include <JavaScriptCore/Forward.h>
#include <JavaScriptCore/JSCJSValue.h>
#include <span>
#include <wtf/Function.h>
#include <wtf/Ref.h>
#include <wtf/RefCountedAndCanMakeWeakPtr.h>

namespace WebCore {

class ReadableStream;
class ReadableStreamDefaultReader;
class SinkReadRequest;
template<typename> class ExceptionOr;

class ReadableStreamToSharedBufferSink final : public RefCountedAndCanMakeWeakPtr<ReadableStreamToSharedBufferSink> {
public:
    using Result = Variant<std::nullptr_t, std::span<const uint8_t>, JSC::JSValue, Exception>;
    using Callback = Function<void(Result&&)>;
    static Ref<ReadableStreamToSharedBufferSink> create(Callback&& callback) { return adoptRef(*new ReadableStreamToSharedBufferSink(WTF::move(callback))); }
    ~ReadableStreamToSharedBufferSink();

    void pipeFrom(ReadableStream&);
    void clearCallback();
    bool hasCallback() const { return !!m_callback; }

private:
    explicit ReadableStreamToSharedBufferSink(Callback&&);

    friend class SinkReadRequest;
    void enqueue(const Ref<JSC::Uint8Array>&);
    void close();
    void error(Exception&&);
    void error(JSC::JSValue);

    Callback m_callback;
    RefPtr<ReadableStreamDefaultReader> m_reader;
    RefPtr<SinkReadRequest> m_readRequest;
};

} // namespace WebCore
